-- main.lua for threadDemo6.love
function love.load()
	thread			= love.thread.newThread( 'thread', 'thread.lua' )
	counter 		= 0
	msg				= {}
	gr, lt			= love.graphics, love.timer
	fontsize		= 15
	gr.setFont( gr.newFont( fontsize ) )
	pi, sin, cos	= math.pi, math.sin, math.cos
	cx, cy, rd		= 200, 200, 125 -- center of clock
	thread_started	= false
	thread_start	= 5				-- delay start of thread by 5 seconds
	end

function love.update()
	if lt.getTime()	> thread_start then
		if  not thread_started then
			thread:start()
			thread:set( 'counter_limit', 10 )	-- make available to thread
			thread_started		= true
			else
			if thread:peek('image_loaded') and not image_available then
				imageData		= thread:get('image')
				image			= love.graphics.newImage(imageData)
				image_available = true
				end
			end
		end
	end

function love.draw()
	drawClock()
	showStatus()
	gr.print( math.floor( lt.getTime()), cx-10, cy+rd+2*fontsize )
	if image_available  then
		love.graphics.draw( image, hx-.2*rd, hy-.2*rd, 0, .2, .2 )
		showStatus()
		else
		if thread:peek( 'image_acquiring' ) then
			gr.print( "Image loading in thread: "..math.floor(lt.getTime()), 100, 200 )
			else
			gr.print( "Thread starts in "..thread_start.." sec: "..math.floor(lt.getTime()), 100, 200 )
			end
		end
	if thread:peek( 'counter_active' ) then
		gr.print( "Counter is running ", 130, 200 )
		end
	if thread:peek( 'fab_calc' ) then
		gr.print( "Calculating fab #37", 130, 200 )
		end
	if image_available and not thread:peek( 'thread_running' ) then
		gr.print( "Demo complete!", 140, 200 )
		end
	if thread:peek( 'fab_ready' ) then
		gr.print( "37th Fibonacci value is "..thread:peek( 'fab_val' ), 70, 375 )
		end
	end

function drawClock()
	gr.setColor( 0, 0, 255, 255 )
	gr.circle( 'line', cx, cy, rd, 36 )
	hx = rd * cos( pi * (lt.getTime()/15-.5)) + cx
	hy = rd * sin( pi * (lt.getTime()/15-.5)) + cy
	gr.setColor( 255, 0, 0, 255 )
	gr.line( cx, cy, hx, hy )
	gr.setColor( 255, 255, 255, 255 )
	end

function showStatus()
	local msg_names = thread:getKeys()	-- get names of all items set by thread
	for i = #msg_names, 1, -1 do	-- 'image' contains userdata so can't print
		if msg_names[i] == "image" then table.remove( msg_names, i ) end
		end
	local locx, locy = 10, 7
	if thread:peek( 'thread_running' ) then
	gr.print( "Thread Status", locx, locy )
	gr.rectangle( 'line', 5, 2, 175, 160 )
	for i = 1,#msg_names do msg[i] = tostring(thread:peek(msg_names[i])) end
	for i = 1, #msg do
		gr.print( msg_names[i]..": "..msg[i], locx, locy + (i) * fontsize )
		end
	end
	end

function love.keypressed( key )
	if key == 'escape'	then love.event.push('quit') end
	end
